@@ -39,8 +39,8 @@ class Bicubic(Kernel):
     :param c: C-param for bicubic kernel
     """
 
-    scale_function = core.proxied.resize.Bicubic
-    descale_function = core.proxied.descale.Debicubic
+    scale_function = core.lazy.resize.Bicubic
+    descale_function = core.lazy.descale.Debicubic
 
     def __init__(self, b: float = 0, c: float = 1 / 2, **kwargs: Any) -> None:
         self.b = b
@@ -192,8 +192,8 @@ class BicubicAuto(Kernel):
     b + 2c = target - 1 for downsizing
     """
 
-    scale_function = core.proxied.resize.Bicubic
-    descale_function = core.proxied.descale.Debicubic
+    scale_function = core.lazy.resize.Bicubic
+    descale_function = core.lazy.descale.Debicubic
 
     def __init__(self, b: float | None = None, c: float | None = None, target: float = 1.0, **kwargs: Any) -> None:
         if None not in {b, c}:
