@@ -1,9 +1,8 @@
 from __future__ import annotations
 
-from functools import wraps
-from typing import Any, Callable, cast, overload
+from typing import Any, Callable, overload
 
-from vstools import F, HoldsVideoFormatT, MatrixT, VideoFormatT, VSFunction, core, inject_self, vs
+from vstools import HoldsVideoFormatT, MatrixT, VideoFormatT, VSFunction, core, inject_self, vs
 
 from .abstract import Kernel
 from .bicubic import Bicubic
@@ -25,69 +24,60 @@ class FmtConv(Kernel):
     * fmtconv
     """
 
-    @staticmethod
-    def wrap_fmtc_func(function: F) -> VSFunction:
-        @wraps(function)
-        def _wrapper(self: FmtConv, clip: vs.VideoNode, **kwargs: Any) -> Any:
-            assert clip.format
+    def scale_function(self, clip: vs.VideoNode, **kwargs: Any) -> vs.VideoNode:
+        assert clip.format
 
-            bicubic = Bicubic()
+        def _check_fmt(fmt: int | vs.PresetFormat | vs.VideoFormat) -> tuple[vs.VideoFormat, bool]:
+            fmt = core.get_video_format(fmt)
 
-            def _check_fmt(fmt: int | vs.PresetFormat | vs.VideoFormat) -> tuple[vs.VideoFormat, bool]:
-                if not isinstance(fmt, vs.VideoFormat):
-                    fmt = core.get_video_format(fmt)
+            return fmt, ((
+                fmt.bits_per_sample == 32 and fmt.sample_type == vs.FLOAT
+            ) or (
+                fmt.bits_per_sample == 16 and fmt.sample_type == vs.INTEGER
+            ))
 
-                return fmt, (
-                    fmt.bits_per_sample == 32 and fmt.sample_type == vs.FLOAT
-                ) or (
-                    fmt.bits_per_sample == 16 and fmt.sample_type == vs.INTEGER
-                )
+        in_fmt = clip.format
+        out_fmt = None
 
-            in_fmt = clip.format
-            out_fmt = None
+        csp = kwargs.get('csp', None)
+        bits = kwargs.get('bits', None)
+        flt = kwargs.get('flt', 0)
 
-            csp = kwargs.get('csp', None)
-            bits = kwargs.get('bits', None)
-            flt = kwargs.get('flt', 0)
+        if csp:
+            out_fmt, valid = _check_fmt(csp)
 
-            if csp:
-                out_fmt, valid = _check_fmt(csp)
-
-                if not valid:
-                    kwargs.pop('csp')
-                else:
-                    out_fmt = None
+            if not valid:
+                kwargs.pop('csp')
             else:
+                out_fmt = None
+        else:
+            out_fmt = in_fmt
+
+        if bits:
+            if not out_fmt:
                 out_fmt = in_fmt
 
-            if bits:
-                if not out_fmt:
-                    out_fmt = in_fmt
+            out_fmt = out_fmt.replace(bits_per_sample=bits)
 
-                out_fmt = out_fmt.replace(bits_per_sample=bits)
+        if not _check_fmt(in_fmt)[1]:
+            clip = Bicubic.resample(
+                clip, in_fmt.replace(bits_per_sample=16 * (1 + flt), sample_type=vs.SampleType(flt))
+            )
+        if out_fmt:
+            out_fmt, valid = _check_fmt(out_fmt)
+            if valid:
+                kwargs['csp'] = out_fmt
+                out_fmt = None
 
-            if not _check_fmt(in_fmt)[1]:
-                clip = bicubic.resample(
-                    clip, in_fmt.replace(bits_per_sample=16 * (1 + flt), sample_type=vs.SampleType(flt))
-                )
-            if out_fmt:
-                out_fmt, valid = _check_fmt(out_fmt)
-                if valid:
-                    kwargs['csp'] = out_fmt
-                    out_fmt = None
+        filtered = clip.fmtc.resample(**kwargs)
 
-            filtered = function(clip, **kwargs)
+        if not out_fmt:
+            return filtered
 
-            if not out_fmt:
-                return filtered
+        assert filtered.format
+        return Bicubic.resample(filtered, out_fmt)
 
-            assert filtered.format
-            return bicubic.resample(filtered, out_fmt)
-
-        return cast(VSFunction, _wrapper)
-
-    scale_function = wrap_fmtc_func(core.proxied.fmtc.resample)
-    descale_function = wrap_fmtc_func(core.proxied.fmtc.resample)
+    descale_function = scale_function
 
     kernel: str
     """Name of the fmtconv kernel"""
@@ -139,7 +129,7 @@ class FmtConv(Kernel):
         ...
 
     @inject_self.cached  # type: ignore
-    def shift(  # type: ignore
+    def shift(
         self, clip: vs.VideoNode,
         shifts_or_top: float | tuple[float, float] | list[float] | None = None,
         shift_left: float | list[float] | None = None, **kwargs: Any
