@@ -16,15 +16,14 @@ __all__ = [
 class Point(Kernel):
     """Built-in point resizer."""
 
-    scale_function = core.proxied.resize.Point
-    descale_function = core.proxied.resize.Point
+    scale_function = descale_function = core.lazy.resize.Point
 
 
 class Bilinear(Kernel):
     """Built-in bilinear resizer."""
 
-    scale_function = core.proxied.resize.Bilinear
-    descale_function = core.proxied.descale.Debilinear
+    scale_function = core.lazy.resize.Bilinear
+    descale_function = core.lazy.descale.Debilinear
 
 
 class Lanczos(Kernel):
@@ -38,8 +37,8 @@ class Lanczos(Kernel):
     :param taps: taps param for lanczos kernel
     """
 
-    scale_function = core.proxied.resize.Lanczos
-    descale_function = core.proxied.descale.Delanczos
+    scale_function = core.lazy.resize.Lanczos
+    descale_function = core.lazy.descale.Delanczos
 
     def __init__(self, taps: int = 3, **kwargs: Any) -> None:
         self.taps = taps
