@@ -37,8 +37,8 @@ class Spline16(Kernel):
     * VapourSynth-descale
     """
 
-    scale_function = core.proxied.resize.Spline16
-    descale_function = core.proxied.descale.Despline16
+    scale_function = core.lazy.resize.Spline16
+    descale_function = core.lazy.descale.Despline16
 
 
 class Spline36(Kernel):
@@ -50,8 +50,8 @@ class Spline36(Kernel):
     * VapourSynth-descale
     """
 
-    scale_function = core.proxied.resize.Spline36
-    descale_function = core.proxied.descale.Despline36
+    scale_function = core.lazy.resize.Spline36
+    descale_function = core.lazy.descale.Despline36
 
 
 class Spline64(Kernel):
@@ -63,8 +63,8 @@ class Spline64(Kernel):
     * VapourSynth-descale
     """
 
-    scale_function = core.proxied.resize.Spline64
-    descale_function = core.proxied.descale.Despline64
+    scale_function = core.lazy.resize.Spline64
+    descale_function = core.lazy.descale.Despline64
 
 
 class Spline100(Spline):
